/*
 * avatarwidgetmodel.h
 *
 * This file is part of contacts widgets
 *
 * Copyright (C) 2009 Nokia Corporation. All rights reserved.
 *
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved.
 * Copying, including reproducing, storing, adapting or translating,
 * any or all of this material requires the prior written consent of
 * Nokia Corporation. This material also contains confidential
 * information which may not be disclosed to others without the prior
 * written consent of Nokia.
 */

#ifndef AVATARWIDGETMODEL_H_
#define AVATARWIDGETMODEL_H_

#include <mimagewidgetmodel.h>
#include <qcontactdetails.h>
#include <qcontactfetchrequest.h>

QTM_USE_NAMESPACE

class Q_DECL_EXPORT AvatarWidgetModel : public MImageWidgetModel
{
    Q_OBJECT
    M_MODEL_WITH_PRIVATE(AvatarWidgetModel)

    M_MODEL_PROPERTY(quint32, contactId, ContactId, true, 0)
    M_MODEL_PROPERTY(bool, nameLabelDisplayed, NameLabelDisplayed, true, 0)
    // we have this fields bellowe because it is possible to set outside what to present without
    // the requesting data
    M_MODEL_PROPERTY(QString, avatar, Avatar, false, QString())
    M_MODEL_PROPERTY(QPixmap, avatarPixmap, AvatarPixmap, false, NULL)   // TODO: I guess nobody uses this property longer.
    M_MODEL_PROPERTY(QString, avatarLogicalId, AvatarLogicalId, false, QString())
    M_MODEL_PROPERTY(QString, nameLabel, NameLabel, true, QString())
    M_MODEL_PROPERTY(QString, nameInitials, NameInitials, true, QString())
    M_MODEL_PROPERTY(QString, statusMessage, StatusMessage, true, QString())
    M_MODEL_PROPERTY(bool, waitingForApproval, WaitingForApproval, true, false)

    /// @note autogenerated code doesnt work for QContactPresence::PresenceState so that is moved to private class

public:
    /**
     * \! brief - tries to locate image with given filename in search directories and
     * then sets avatar (setAvatar()) to found or default avatar image.
     * So, if You are using setAvatar() make sure that file exist
     * Returns true if file exists, otherwise false
     */
    bool setAvatarFilename(const QString &avatar);

    /**
     * \! brief - sets the QContact. This is useful for application that has a
     * external contact request manager
     */
    void setContact(const QContact &contact);

    /*
     * \! brief - access set (through setContact) or fetched QContact (if using setContactId).
     * This is useful for application that set QContactId and then accesses the result.
     */
    QContact contact() const;

    static const char* const PresenceState;
    QContactPresence::PresenceState presenceState() const;
    void setPresenceState(const QContactPresence::PresenceState &presenceState);

    /**
     * \! brief - static method for the list of the details needed for the QContact.
     */
    static QStringList detailsRequired();

    Q_DECL_DEPRECATED QString avatarNameLabel();

 signals:
    /*!
     * Signal to inform about the changed presence state of the avatar.
     */
    void stateChanged(const QContactPresence::PresenceState &status);
    /**
     * Signals when the contact has a new status message.
     */
    void statusMessageChanged(const QString& statusMessage);

private slots:
    void onContactsChanged(const QList<QContactLocalId>&);
    void onRequestProgress();
    void onRequestStateChanged(QContactAbstractRequest::State state);

protected:

    void triggerUpdate();
    /*
     * Not an API - called from controller - AvatarWidget only
     * Important to separate - when users feed the data to avatars without fetching data
     * by avatar model itself, this is not called. it is called if users setContactId
     * - then the rest of data is expect to come from storage - in that case it makes
     * sence that avatar model updates itself when storage changes
     */
    void initializeListeningForContactStorageChanges();

    void cancelListeningForContactStorageChanges();

friend class AvatarWidget;

private:
    QContactPresence::PresenceState calculateMasterPresence(QList<QContactPresence> presences);
    bool isAvatarLocalFilePath(QString avatarFilePath );
    bool isAvatarURIFilePath(QString avatarFilePath );
    bool isAvatarFilename(QString avatarFilePath );
    bool isAvatarLogicalId(QString avatarFilePath );
};

#endif /* AVATARWIDGETMODEL_H_ */
