/* * This file is part of contactui *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CARDBASEWIDGET_H
#define CARDBASEWIDGET_H

// Qt includes
#include <QContact>
#include <QContactOnlineAccount>
#include <QContactPresence>
#include <QContactFetchRequest>

// M includes
#include <MButton>
#include <MGridLayoutPolicy>
#include <MStylableWidget>

// Forward declarations
class AvatarWidget;
class ContactListener;
class MLabel;
class AvatarSelector;

QTM_USE_NAMESPACE

/**
 * \class CardBaseWidget
 * \brief This is the widget that contains a contact's avatar, name, and status.
 **/
class CardBaseWidget : public MStylableWidget
{
    Q_OBJECT;
    Q_ENUMS(Details)
    Q_ENUMS(DetailsRowOrder)
    Q_ENUMS(DetailsColumnOrder)

public:
    /** Create a CardBaseWidget.
     *
     * See also setContactListener().
     *
     * \param listener The listener that provides the contact details.
     * \param parent The (optional) owner of this instance.
     */
    explicit CardBaseWidget(bool temporary, QGraphicsItem *parent = 0);

    void setContact(const QContact &contact);
    void setContactListener(ContactListener *listener);
    void deleteAvatarSelector();

    enum Details {
        COMPANY = 0,
        STATUS,
        BRANDING,
        NUM_DETAILS
    };

    enum DetailsRowOrder {
        TOP_SPACER = 0,
        AVATAR_ROW,
        NAME_ROW,
        COMPANY_ROW,
        STATUS_ROW,
        BRANDING_ROW,
        NUM_DETAILS_ROW
    };

    enum DetailsColumnOrder {
        AVATAR_COL = 0,
        NAME_COL,
    };

protected slots:
    void onContactChanged();
    void onContactUpdated(const QStringList &definitionNames);
    void onImageClicked();
    void saveSelection(QImage image);
    void saveUrlSelection(const QString &imageUrl);
    void connectClickedSignal();
    void disconnectClickedSignal();
    void onNameOrderSettingChanged();

private:
    void updateForContact(const QContact& contact);
    void updateName(const QContact& contact);
    void updateCompany(const QContact& contact);
    void updateAvatar(const QContact& contact,  bool ignoreQAvatar = false);
    void updatePresence(const QContact& contact);
    void startSaveRequest(const QContact &contact);
    void updateStatus(const QContact& contact);
    void updateDetailsVisibility();
    void updateLabelVisibility(MLabel *label, int detail, int position);
    void updateSignals(const QContact& contact);
    bool scaleDownAvatar(const QString &avatarFilePath);
    bool hasPendingBuddyApprovals(const QList<QContactPresence> &presences) const;

    ContactListener *mContactListener;

    MGridLayoutPolicy *mPortraitPanelPolicy;
    MGridLayoutPolicy *mLandscapePanelPolicy;

    AvatarWidget *mAvatarWidget;
    AvatarSelector *mAvatarSelector;
    MLabel *mLabelName;
    MLabel *mLabelCompany;
    MLabel *mLabelStatus;
    MLabel *mLabelBranding;
    int  mPreferredWidth;
    int  mPreferredHeight;
    bool mCurrentTemporaryMode;
    bool mIsSimContact;
    bool mDetailVisible[NUM_DETAILS];
    bool mImageSelected;
};

#endif // CARDBASEWIDGET_H
