/* * This file is part of libcontacts *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef CONTACTACCOUNTPROVIDER_H_
#define CONTACTACCOUNTPROVIDER_H_

#include <QObject>

#include <Accounts/Provider>

/*!
 * \class ContactAccountProvider
 * \brief Class contening cached information about service
 */
class ContactAccountProvider : public QObject
{
    Q_OBJECT

public:
    ContactAccountProvider(const QString &name) : mName(name) {}

    /*!
     * Provider id (e.g. 'google', 'facebook', 'skype').
     */
    const QString& name() const { return mName; }
    void setName(const QString& name) { mName = name; }

    /*!
     * Localized display name (e.g. 'Google', 'Facebook', 'Skype').
     */
    const QString& displayName() const { return mDisplayName; }
    void setDisplayName(const QString& name) { mDisplayName = name; }

    /*!
     * Provider icon name.
     */
    const QString& icon() const { return mIcon; }
    void setIcon(const QString& icon) { mIcon = icon; }

private:
    QString mName;
    QString mDisplayName;
    QString mIcon;
};

#endif /* CONTACTACCOUNTPROVIDER_H_ */
