/* * This file is part of libcontacts *
 * Copyright (C) 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright
 * controlled by Nokia Corporation. All rights are reserved. Copying,
 * including reproducing, storing, adapting or translating, any or all of
 * this material requires the prior written consent of Nokia Corporation.
 * This material also contains confidential information which may not be
 * disclosed to others without the prior written consent of Nokia.
 */

#ifndef CONTACTACCOUNTSERVICE_H_
#define CONTACTACCOUNTSERVICE_H_

#include <QObject>

#include <Accounts/Service>

#include "contactaccountprovider.h"

/*!
 * \class ContactAccountService
 * \brief Class contening cached information about service
 */
class ContactAccountService : public QObject
{
    Q_OBJECT

public:
    ContactAccountService(const QString &name) : mName(name), mProvider(0) {}

    /*!
     * Service id (e.g. 'google-talk', 'msn-nm', 'skype').
     */
    const QString& name() const { return mName; }
    void setName(const QString& name) { mName = name; }

    /*!
     * Localized display name (e.g. 'Google', 'Facebook', 'Skype').
     */
    const QString& displayName() const { return mDisplayName; }
    void setDisplayName(const QString& name) { mDisplayName = name; }

    /*!
     * Service icon. Used when referring to that service in UI.
     */
    const QString& icon() const { return mIcon; }
    void setIcon(const QString& icon) { mIcon = icon; }

    /*!
     * Provider information (display name, icon)
     */
    ContactAccountProvider* provider() const { return mProvider; }
    void setProvider(ContactAccountProvider *provider) { mProvider = provider; }

    /*!
     * Provider icon. Used when referring to that account in UI.
     */
    const QString providerIcon() const { return mProvider ? mProvider->icon() : QString(); }

    /*!
     * Provider localized name (e.g. 'Google', 'Facebook', 'Skype').
     */
    const QString providerName() const { return mProvider ? mProvider->displayName() : QString(); }

private:
    QString mName;
    QString mDisplayName;
    QString mIcon;
    ContactAccountProvider *mProvider;
};

#endif /* CONTACTACCOUNTSERVICE_H_ */
