/* * This file is part of contactui *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTCARDPAGE_H
#define CONTACTCARDPAGE_H

#include <QPair>
#include <QList>
#include <QContact>
#include <QContactPresence>
#include <QContactOnlineAccount>

#include <MApplicationPage>
#include <MOrientationChangeEvent>
#include <qcontactdetail.h>

QTM_USE_NAMESPACE


class ContactListener;

/**
 * \class ContactCardPage
 * \brief This is the page containing the contact card widgets
 */
class ContactCardPage: public MApplicationPage
{
    Q_OBJECT

public:

    /**
     * \brief Creates the ContactCardPage.
     **/
    explicit ContactCardPage();

    /**
     * \brief Destruct ContactCardPage.
     **/
    ~ContactCardPage();

    /**
     * \brief Create the UI
     **/
    virtual void createContent();

Q_SIGNALS:
    void dismissed();

public slots:
    void setContact(const QContactId &contactId, bool external = false);
    void setContact(const QContactLocalId &contactId, const QString &contactManagerUri = QString(), bool external = false);
    void setContact(const QContact &contact, bool external = false);
    /*
     * Pre-creates heavy stuff
     */
    void preCreate();

protected slots:
    virtual void dismissEvent(MDismissEvent *event);
    virtual void appear(MWindow *window, MSceneWindow::DeletionPolicy policy = MSceneWindow::KeepWhenDone);
    void appearPage();

private:
    // Please, don't add data members here. Add them to ContactCardPage::Private.
    class Private;
    Private * const d;
};

#endif // CONTACTCARDPAGE_H
