/* * This file is part of contacts/contactui*
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTLISTPAGE_H
#define CONTACTLISTPAGE_H

// Qt includes
#include <QDebug>
#include <QTime>
#include <QGraphicsLinearLayout>
#include <QDBusPendingCallWatcher>

// M includes
#include <MApplicationPage>
#include <MTextEdit>
#include <MKeyboardStateTracker>
#include <MLayout>
#include <MGridLayoutPolicy>
#include <MOrientationChangeEvent>
#include <MStylableWidget>
class MList;

// Us
#include "contactmanager.h"
#include "contactsgroupingmodel.h"
#include "contactsguiactionresult.h"
#include "contactslistsettings.h"
#include "importprogresswidget.h"

class ContactListPagePrivate;
class ContactListItemData;

/*!
 * \class ContactListPage
 * \brief
 * ApplicationPage presenting contact list. Containing single MList, content filter combo and
 * linking ContactModel to m list for sorting and filtering
 */
class Q_DECL_EXPORT ContactListPage: public MApplicationPage
{
    Q_OBJECT

    Q_PROPERTY(bool mainList READ isMainList WRITE setMainList)

public:
    /**
     * \brief Create the object.
     **/
    ContactListPage();
    /**
     * \brief Destruct object.
     **/
    ~ContactListPage();

    /*! Retrieve the model for this page.
     */
    ContactsGroupingModel *model() const;

    //!\reimp
    virtual void createContent();

    void setTitleText(const QString &title);

    QString titleText() const;

    /**
     * \brief Set empty state text
     */
    void setEmptyStateText(const QString &emptyStateText);

    void setTime(const QTime &time);

    bool hasContacts();

    void setMainList(bool value);
    bool isMainList() const;

    void setForceSearchVisible(bool force);

    void scrollToTop();

    void clearSearchFilter();

    void setDeepLink();

Q_SIGNALS:
    /*!
     * Emit signal when contact list is not empty anymore.
     * This signal is actually sent from the ContactsListModel and proxied
     * from the page.
     */
    void contactListNotEmpty();

private Q_SLOTS:
    void scrollToPreviousContact();
    void showAddContactPage();
    void showAddGroupPage();
    void updateContactListActions();

    void onGroupByChanged();
    void onShown();
    void onAppeared();
    void onDisappeared();
    void onItemClick(ContactListItemData *data);
    void onItemLongTapped(ContactListItemData *data, const QPointF &position);
    void onSearchWidgetVisible(bool visible);
    void onImportProgressWidgetVisible(bool visible);
    void onContactAddRequestFinished(const QContactId &id);

private:
    void createActions();
    void contactOpen(const ContactListItemData &data);
    QString msToTimeString(int ms);

    ContactListPagePrivate * const d;
    ContactsGuiActionResult::SharedPointer mLastResult;
};

#endif  // CONTACTLISTPAGE_H
