/* * This file is part of contacts *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTMANAGER_H
#define CONTACTMANAGER_H

#include <qcontactmanager.h>
#include <QContactOnlineAccount>

// needed to work around a circular dependency between the voicemailstore and the contactsutils
// i can't change the voicemailstore interface because some external apps are relying on it
// (even though its marked private)
static const QLatin1String VOICEMAIL_CONTACT_GUID("9aeeea49-fab9-4d4e-b0cc-497f2aeac9a8");

QTM_USE_NAMESPACE

/**
 * Provides a thin wrapper around QContactManager instances, sharing access
 * to a single instance of each QContactManager plugin, for efficiency.
 */
class ContactManager
{
 public:
    /**
     * Public static getter for the singleton instance by manager name.
     *
     * @return CStateManager instance or NULL in case of memory allocation error.
     */
    static QContactManager* instance (const QString& managerName = QString::fromLatin1("tracker"));

    /*!
     * Public static getter for the singleton instance by manager uri.
     */
    static QContactManager* instanceFromUri (const QString& managerUri);


    static QString Social; // "social"
    static QString Tracker; // "tracker"
    /*!
     * QContactManager("simcard") is very expensive - instantiate it
     * only when necessary.
     * \sa isSIMCardContact()
     */
    static QString SIMCard; // "simcard"

    static QString TrackerImGroupsFeature;
    static QString TrackerImGroupsContactType;

    static QStringList availableManagers();

    static bool isTrackerContact(const QContactId &id);
    static bool isSocialContact(const QContactId &id);
    static bool isSIMCardContact(const QContactId &id);

    // is voicemail contact
    static bool isVoicemail(const QContact &contact);

    // is either tracker or social self contact
    static bool isSelfContact(const QContactId &id);

    // is tracker contact and doesn't have telepathy sync target
    static bool isLocalContact(const QContact &contact);

    // is contact's sync target telepathy (e.g. gtalk, skype...)
    static bool isSyncTargetTelepathy(const QContact &contact);

    // is contact's sync target MfE (Mail For Exchange)
    static bool isSyncTargetMfe(const QContact &contact);

    static bool isForceAutomergedContact(const QContact &contact);
    static bool isForceAutomergedAccount(const QContactOnlineAccount &account);

    // is contact local and linked to at least one service
    static bool isLocalContactLinkedToService(const QContact &contact);
    static bool isUnmergeableContact(const QContact &contact);
    static bool isRemovableContact(const QContact &contact);
    static bool isMergedServiceContact(const QContact &contact);

    /*!
     * Transient contacts don't have display label, need to synthesize it until it is generated
     * by default for QContact
     */
    static QString synthesizedDisplayLabel(const QContact &contact);

    static void cleanup();

 private:
    ContactManager(); // Private to make instantiation impossible

    //! the singleton instances of actual contact managers
    static QMap<QString, QContactManager*> instances;
};

QTM_BEGIN_NAMESPACE
inline uint qHash(const QContactId &id)
{
    return id.localId() + qHash(id.managerUri());
}
QTM_END_NAMESPACE

#endif // CONTACTMANAGER_H

