/* * This file is part of contacts *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTMODELCACHE_H
#define CONTACTMODELCACHE_H

#include <QContactManager>
#include <QContact>
#include <QContactAbstractRequest>
#include <workerthread.h>
#include <contactmodel.h>

QTM_USE_NAMESPACE


/*!
 * \class ContactModelCache
 * Fills ContactModel from cache, serializes model to cache
 */
class ContactModelCache
{
public:
    /*!
     * \fn ContactModelCache::load()
     * Loads content to \a model for given contact \a manager.
     * After loading:
     * - starts fetch all ids - to handle contacts removed
     * - starts fetch of contacts changed/added since. In case of problem with timestamp - fetches all.
     * If restore from cache was not successful (no cache) returns false
     */
    bool load(const ContactModel *model, const QContactManager * const manager) const;

    /*!
     * \fn ContactModelCache::store()
     * Stores \model content for given contact \a manager.
     */
    void store(const ContactModel *model, const QContactManager * const manager) const;

private:
    void serialize(QDataStream &stream, const QHash <QContactLocalId, QContact> &contacts) const;
    void unserialize(QDataStream &stream, QHash <QContactLocalId, QContact> &contacts, const QContactManager * const manager) const;
};

#endif // CONTACTMODELCACHE_H

