/* * This file is part of contacts/contactui*
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef CONTACTPICKERCONTROLLER_H
#define CONTACTPICKERCONTROLLER_H

#include <QObject>
#include <qcontact.h>

QTM_USE_NAMESPACE

class MApplicationPage;
class ContactPickerPage;
class ContactPickerControllerPrivate;

class Q_DECL_EXPORT ContactPickerController : public QObject
{
    Q_OBJECT

public:
    virtual ~ContactPickerController();

    /**
     * \brief Returns an instance of ContactPickerPage
     */
    const MApplicationPage *page();

    /**
     * \brief Set a string to filter the contact list
     *
     * \param filter - a string to filter the contact list
     */
    void setFilter(const QString& filter);

    /**
     * \brief Returns the current filter
     *
     * \returns - a string containing the current filter
     */
    QString filter();

    /**
     * \brief Changes the title of the ContactPickerPage instance
     */
    void setTitleText(const QString& title);

     /**
     * \brief Gets the current title of the ContactPickerPage instance
     */
    QString titleText();

    /**
     * \brief Enable "Select/Clear All" button
     */
    void setSelectClearAllEnabled(bool enabled);

    /**
     * \brief Gets the current state of "Select/Clear All" button
     */
    bool isSelectClearAllEnabled();

Q_SIGNALS:
    void contactsPicked(const QList<QContactId> &);
    void contactPicked(const QContact &);

private:
    explicit ContactPickerController(ContactPickerPage *page, QObject *parent = 0);
    friend class ContactsGui;

private:
    ContactPickerControllerPrivate *d;
};

#endif
