/* * This file is part of contacts/contactui*
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef EMPTYSTATEPAGE_H
#define EMPTYSTATEPAGE_H

// Qt includes
#include <QGraphicsLinearLayout>

// M includes
#include <MApplicationPage>
#include <QPropertyAnimation>

class QPropertyAnimation;
class MLayout;
class MLabel;

/**
 * \class EmptyStatePage
 * \brief This is a common empty state page containing all empty state modes
 */
class Q_DECL_EXPORT EmptyStatePage : public MApplicationPage
{
    Q_OBJECT

public:
    /**
     * \brief Creates the EmptyStatePage.
     *
     * \param contactExist flag to inform of existing contacts
     **/
    explicit EmptyStatePage( bool contactsExist );
    ~EmptyStatePage();

    void createContent();

Q_SIGNALS:
    void emptyPageSkipped();

private Q_SLOTS:
    void onContactListNotEmpty();
    void onImportFromPhoneClicked();
    void onImportFromServiceClicked();
    void onEmptyStateSkipped();
    void onAnimationDone();
    void onImportOptionSelected();

private:
    void updateText(bool animate = false);

    QGraphicsLinearLayout *mMainLayout;
    MLabel  *mInfoLabel;
    MLabel  *mButtonsTitleLabel;
    QPropertyAnimation *mAnimation;
    QString mButtonsTitleTextHasContacts;
    QString mInfoTextNoContacts;
    QString mInfoTextHasContacts;

    bool mContactsExist;
};

#endif  // EMPTYSTATEPAGE_H
