/* * This file is part of contacts/contactui*
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef IMPORTPROGRESSWIDGET_H
#define IMPORTPROGRESSWIDGET_H

#include <MStylableWidget>
#include <QStringList>
#include <QString>
#include <QTimer>

class QGraphicsLinearLayout;
class MImageWidget;
class MLabel;
class MProgressIndicator;
class ContactImportProcessor;
class ContactsImportProgressInterface;
class QDBusPendingCallWatcher;
class QTimer;

class ImportProgressWidget : public MStylableWidget
{
    Q_OBJECT

public:
    ImportProgressWidget(QGraphicsItem *parent = 0);
    ~ImportProgressWidget();

    void start();


public slots:
    // Result from the async DBus call to "com.nokia.contacts.importprogress.hasActiveImports
    void hasActiveImportsFinished(QDBusPendingCallWatcher *);

    // Slot for the signal that a contact import has started. Sent by contactsd over DBus.
    // Signal is "com.nokia.contacts.importprogress.importStart"
    void onContactImportStarted(const QString &service = QString());

    void onContactImportStateChanged(const QString &finishedService,
                                     const QString &newService);
    // Slot for the signal that a contact import has finished. Sent by contactsd over DBus.
    // The signal contains also the results.
    // Signal is "com.nokia.contacts.importprogress.importFinished(added, deleted, merged)"
    void onContactImportFinished(int added = 0, int deleted = 0, int merged = 0);

    // Slot for the signal that a contact import has failed.
    void onContactImportFailed(int code, const QString &message);

    // Slot for the signal that an import action (vcard file, SIM card) has started.
    void onImportActionStarted(const QString &service);

    // Slot for the signal that an import action has finished
    void onImportActionFinished(const QString &service, int added = 0, int failed = 0, int merged = 0);

    // Slot for the signal that a contact export has started.
    void onExportActionStarted(const QString &service = QString());

    // Slot for the signal that a contact export has finished.
    void onExportActionFinished(const QString &service);

    void onSwitcherEntered();

signals:
    void visible(bool isVisble);

private slots:
    void onContactImportProcessed(const ContactImportProcessor &result);
    void onSocialImportStarted(const QString &service, const QString &accountId);
    void onSocialImportFinished(const QString &service, const QString &accountId, int added);
    void onImportTimeout();
    void onResultTimeout();

private:
    enum ServiceTypes {
        IMPORT_TYPE = 0,
        IMPORT_ACTION_TYPE = 1,
        EXPORT_ACTION_TYPE = 2,
        IMPORT_SOCIAL_TYPE = 3,
        TYPE_NUMBER
    };

    bool hasActiveImports();
    void updateResults();
    void resetResults();
    void update();
    void startImportTimer();
    void stopImportTimer();
    void showNotification(const QString &text);

    QGraphicsLinearLayout *mLayout;
    QGraphicsLinearLayout *mLabelsLayout;
    MImageWidget *mImage;
    MLabel *mLabelImported;
    MLabel *mLabelAutoMerged;
    MLabel *mLabelAdded;
    MProgressIndicator *mProgressIndicator;

    // The DBus interface to receive notification about contact import start/finish.
    ContactsImportProgressInterface *mContactImportIf;
    QDBusPendingCallWatcher *mWatcher;
    QStringList mActiveServices[TYPE_NUMBER];
    // contacts importing/exporting statisitc
    int mNumOfImported;
    int mNumOfProcessed;
    int mNumOfRetrieved;
    int mNumOfAdded;
    int mNumOfAutoMerged;
    bool mShowAdded;
    bool mShowResults;

    // current widgets visibility
    bool mVisible;
    bool mMergedVisible;
    bool mAddedVisible;
    bool mImageVisible;

    // We need a UI side timeout to prevent spinner spinning forever
    QTimer *mImportTimer;
    QTimer *mResultTimer;
};

#endif // IMPORTPROGRESSWIDGET_H
