/* * This file is part of contacts/libsocialprovider *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef QRELATIONSHIPREPOSITORY_H_
#define QRELATIONSHIPREPOSITORY_H_

#include <QObject>
#include <QMultiHash>
#include <qcontactrelationship.h>
#include <qcontactrelationshipfilter.h>

QTM_USE_NAMESPACE

class QRelationshipRepositoryPrivate;

/*!
 * \class QRelationshipRepository
 * \brief Wrapping storage for contact merging information.
 */
class QRelationshipRepository: public QObject
{
    Q_OBJECT
public:
    virtual ~QRelationshipRepository();

    static QRelationshipRepository *instance();
    static void cleanupInstance();

    // if existing doesn't add duplicates. Returns added - does'nt return ignored duplicates
    QList<QContactRelationship> addRelationships(const QList<QContactRelationship>& contactRelationships);

    QList<QContactRelationship> removeRelationships(const QList<QContactRelationship>& contactRelationships);

    /*!
     * \fn relationships
     * \brief returns list of all relationships
     */
    QList<QContactRelationship> relationships() const;

    /*!
     * \fn contactRelationships
     * \brief returns list of relationships the contact \a contactId is in.
     * \a role in which contactId is in relationship.
     */
    QList<QContactRelationship> contactRelationships(const QContactId &contactId, QContactRelationship::Role role = QContactRelationship::First) const;

signals:
    void relationshipsAdded(const QList<QContactRelationship> &relationships);
    void relationshipsRemoved(const QList<QContactRelationship> &relationships);

private slots:
    void onFileChanged(const QString &path);

private:
    QRelationshipRepository();
    QRelationshipRepository(const QString &filePath);
    void init();
    void setStoragePath(const QString &filePath);
    void setPersistent(bool persistent);
    bool save();
    void listenToFileChange();
    void disableListening();
    void relationshipDiff(const QList<QContactRelationship> &oldRelationships,
                          const QList<QContactRelationship> &newRelationships,
                          QList<QContactRelationship> &removedRelationships,
                          QList<QContactRelationship> &addedRelationships);
    void resetRelationship(const QMultiHash<unsigned int, QContactRelationship> &newRelationshipHash);

private:
    static QRelationshipRepository *_instance;
    QRelationshipRepositoryPrivate *d;
    friend class ut_qtcontacts_social;
    friend class ContactModelPrivate;
    friend class ContactModelCache;
    friend class ContactModel;
};

#endif /* QRELATIONSHIPREPOSITORY_H_ */
