/* * This file is part of contacts *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef SEARCHFIELDWIDGET_H
#define SEARCHFIELDWIDGET_H

#include <QGraphicsLinearLayout>

#include <MStylableWidget>
#include <MTextEdit>
#include <MButton>

class FocusEater : public QObject
{
    Q_OBJECT

    public:
        FocusEater(QObject * parent) : QObject(parent) { }

    signals:
        void focusInEventEated();

    protected:
        bool eventFilter(QObject *obj, QEvent *event)
        {
            if (event->type() == QEvent::FocusIn) {
                QFocusEvent *focusEvent = static_cast<QFocusEvent *>(event);
                if (focusEvent->reason() == Qt::ActiveWindowFocusReason) {
                    emit focusInEventEated();
                    return true;    // eat event
                }
            }
            // standard event processing
            return QObject::eventFilter(obj, event);
        }
};

/**
 * \class SearchFieldWidget
 * \brief This is a MWidget which contains the search field used to filter the contacts in contact list.
 **/
class SearchFieldWidget : public MStylableWidget
{
    Q_OBJECT
public:
    /**
     * \brief Constructor.
     **/
    explicit SearchFieldWidget(QGraphicsItem *parent = 0);

    /**
     * \brief Destructor.
     **/
    virtual ~SearchFieldWidget();

    bool hasFocus() const;
    void setFocus();

    QString editorText();

Q_SIGNALS:

    /*!
     * Signal is emitted when text field content changes
     */
    void textChanged(const QString &searchString);

public Q_SLOTS:
    /*!
     * Slots for manipulating editor's text
     */
    void setEditorText(const QString &text);
    void insertEditorText(const QString &text);
    void removeSymbolFromEnd();
    void clear();
    /*!
     * Close the virtual keyboard.
     */
    void closeVKB();

private Q_SLOTS:
    /*!
     * slot receiving signal of text change from edit-widget
     * This make it possible to emit textChanged( QString &searchString )
     */
    void textFieldTextChanged();

    void onOrientationChanged();

    void onFocusInEventEated();

private:
    QGraphicsLinearLayout *mFilterLayout;
    MTextEdit *mTextEdit;
    MStylableWidget *mMagnifierWidget;
    MStylableWidget *mClearWidget;
};

#endif  // SEARCHFIELDWIDGET_H
