/* * This file is part of contactui *
 * Copyright © 2009 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.
 * Contact: Aleksandar Stojiljkovic <aleksandar.stojiljkovic@nokia.com>
 * This software, including documentation, is protected by copyright controlled by
 * Nokia Corporation. All rights are reserved. Copying, including reproducing, storing,
 * adapting or translating, any or all of this material requires the prior written consent
 * of Nokia Corporation. This material also contains confidential information which may
 * not be disclosed to others without the prior written consent of Nokia. */

#ifndef VOICEMAILDIALOG_H
#define VOICEMAILDIALOG_H

// M includes
#include <MSheet>

// People & contacts includes
#include "voicemail.h"

// forward declarations
class VoicemailDialogPrivate;

/**
 * \class VoicemailDialog
 * \brief VoicemailDialog is used to edit numbers of voicemail contact and set the preferred number.
 */
class Q_DECL_EXPORT VoicemailDialog : public MSheet
{
    Q_OBJECT

public:

    /**
     * \brief Constructor
     **/
    VoicemailDialog(bool showAddNewButton = false);

    /**
      * \brief Deconstructor
      **/
    virtual ~VoicemailDialog();

Q_SIGNALS: // SIGNALS
    //! Emitted when dialog closes with accepted result, expect this before  MDialog::finished().
    void preferredVoicemailNumber(const QString &preferredVoicemailNumber,
                                  Voicemail::VoicemailError error);

    //! Emitted when dialog closes with accepted result, expect this before  MDialog::finished().
    void voicemailNumbers(const QList<VoicemailNumber> &voicemailNumbers,
                          Voicemail::VoicemailError error);

protected Q_SLOTS:
    //! Callback for when store is complete and we can emit preferredVoicemailNumber() and voicemailNumbers().
    virtual void onStoreVoicemailNumbersComplete(Voicemail::VoicemailError error);

private Q_SLOTS:
    void onStoreInitComplete();
    void onCancelButtonClicked();
    void onSaveButtonClicked();

private:
    void createHeader();

    VoicemailDialogPrivate * const d;
};

#endif // VOICEMAILDIALOG_H
